@@ -102,6 +102,5 @@ def test_no_subclass(temp_dir, helpers):
         match=re.escape(
             f'Unable to find a subclass of `MetadataHookInterface` in `foo/{DEFAULT_BUILD_SCRIPT}`: {temp_dir}'
         ),
-    ):
-        with temp_dir.as_cwd():
-            CustomMetadataHook(str(temp_dir), config)
+    ), temp_dir.as_cwd():
+        CustomMetadataHook(str(temp_dir), config)
