@@ -19,9 +19,12 @@ class TestErrors:
         reason='No variants for this platform and architecture combination',
     )
     def test_resolution_error(self, platform):
-        with EnvVars({'HATCH_PYTHON_VARIANT_CPU': 'foo'}), pytest.raises(
-            PythonDistributionResolutionError,
-            match=f"Could not find a default source for name='3.11' system='{platform.name}' arch=",
+        with (
+            EnvVars({'HATCH_PYTHON_VARIANT_CPU': 'foo'}),
+            pytest.raises(
+                PythonDistributionResolutionError,
+                match=f"Could not find a default source for name='3.11' system='{platform.name}' arch=",
+            ),
         ):
             get_distribution('3.11')
 
@@ -35,6 +38,14 @@ class TestDistributionVersions:
         assert version.epoch == 0
         assert version.base_version == '3.11.3'
 
+    def test_cpython_standalone_from_legacy_link(self) -> None:
+        url = 'https://github.com/indygreg/python-build-standalone/releases/download/20230507/cpython-3.11.3%2B20230507-aarch64-unknown-linux-gnu-install_only.tar.gz'
+        dist = get_distribution('3.11', url)
+        version = dist.version
+
+        assert version.epoch == 0
+        assert version.base_version == '3.11.3'
+
     def test_cpython_standalone_custom(self):
         name = '3.11'
         dist = get_distribution(name)
@@ -151,8 +162,11 @@ class TestVariantGIL:
         assert 'freethreaded' in dist.source
 
     def test_incompatible(self, platform):
-        with EnvVars({'HATCH_PYTHON_VARIANT_GIL': 'freethreaded'}), pytest.raises(
-            PythonDistributionResolutionError,
-            match=f"Could not find a default source for name='3.12' system='{platform.name}' arch=",
+        with (
+            EnvVars({'HATCH_PYTHON_VARIANT_GIL': 'freethreaded'}),
+            pytest.raises(
+                PythonDistributionResolutionError,
+                match=f"Could not find a default source for name='3.12' system='{platform.name}' arch=",
+            ),
         ):
             get_distribution('3.12')
